==> yonomi_device_widgets-2.12.0.tar.gz: lib/ui/string_constants.dart <==
class StringConstants {
  StringConstants._(); // coverage:ignore-line
  static const String AN_ERROR_OCCURRED = 'An error occurred.';
  static const String DEVICE_IS_JAMMED = 'The device is jammed.';

  static const String PIN_CODE_DELETE_ALERT_CANCEL = 'Cancel';

  static const String PIN_CODE_DELETE_ALERT_MSG_TEXT =
      'Are you sure you wish to delete this PIN Code?';

  static const String PIN_CODE_DELETE_ALERT_OK = 'OK';

  static const String PIN_CODE_DELETE_ALERT_TITLE = 'Delete PIN Code';

  static const String PIN_CODES_DELETE_BUTTON_TEXT = 'Delete PIN Code';

  static const String PIN_CODES_EDIT_PIN_CODE = 'Edit PIN Code';

  static const String PIN_CODES_INPUT_VALID_RANGE_MIN =
      'Please input a value more than the minimum valid range';

  static const String PIN_CODES_INPUT_VALID_RANGE_MAX =
      'Please input a value less than the maximum valid range';

  static const String PIN_CODES_LIST_SCREEN_TITLE = 'PIN Codes';

  static const String PIN_CODES_MANAGE_PIN_CODES = 'Manage PIN Codes';

  static const String PIN_CODES_NEW_PIN_CODE = 'New PIN Code';

  static const String PIN_CODES_NO_CHANGES_MADE = 'No changes were made';

  static const String PIN_CODES_NO_PIN_CODES = 'No PIN Codes Found';

  static const String PIN_CODES_PIN_CODE = 'PIN Code';

  static const String PIN_CODES_PIN_CODE_NAME = 'PIN Code Name';

  static const String PIN_CODES_PIN_CODE_SETTINGS = 'PIN Code Settings';

  static const String PIN_CODES_PLEASE_ENTER_TEXT = 'Please enter some text';

  static const String PIN_CODES_SAVED_CHANGES = 'Saved changes';
}

==> yonomi_device_widgets-2.12.1.tar.gz: lib/ui/string_constants.dart <==
class StringConstants {
  StringConstants._(); // coverage:ignore-line
  static const String AN_ERROR_OCCURRED = 'An error occurred.';
  static const String DEVICE_IS_JAMMED = 'The device is jammed.';

  static const String PIN_CODE_DELETE_ALERT_CANCEL = 'Cancel';

  static const String PIN_CODE_DELETE_ALERT_MSG_TEXT =
      'Are you sure you wish to delete this PIN Code?';

  static const String PIN_CODE_DELETE_ALERT_OK = 'OK';

  static const String PIN_CODE_DELETE_ALERT_TITLE = 'Delete PIN Code';

  static const String PIN_CODES_DELETE_BUTTON_TEXT = 'Delete PIN Code';

  static const String PIN_CODES_EDIT_PIN_CODE = 'Edit PIN Code';

  static const String PIN_CODES_INPUT_VALID_RANGE_MIN =
      'Please input a value more than the minimum valid range';

  static const String PIN_CODES_INPUT_VALID_RANGE_MAX =
      'Please input a value less than the maximum valid range';

  static const String PIN_CODES_LIST_SCREEN_TITLE = 'PIN Codes';

  static const String PIN_CODES_MANAGE_PIN_CODES = 'Manage PIN Codes';

  static const String PIN_CODES_NEW_PIN_CODE = 'New PIN Code';

  static const String PIN_CODES_NO_CHANGES_MADE = 'No changes were made';

  static const String PIN_CODES_NO_PIN_CODES = 'No PIN Codes Found';

  static const String PIN_CODES_PIN_CODE = 'PIN Code';

  static const String PIN_CODES_PIN_CODE_NAME = 'PIN Code Name';

  static const String PIN_CODES_PIN_CODE_SETTINGS = 'PIN Code Settings';

  static const String PIN_CODES_PLEASE_ENTER_TEXT = 'Please enter some text';

  static const String PIN_CODES_CREATING_NEW_PIN = 'Creating new PIN';

  static const String PIN_CODES_SAVING_CHANGES = 'Saving changes';

  static const String PIN_CODES_DELETING_PIN_CODE = 'Deleting PIN Code';

  static const String PIN_CODE_FORM_ERROR =
      'Please fix the errors shown to continue.';
}
